<?php
/*
Plugin Name: FA Sport Odds
Description: Subscribe automatically to our affiliate program and start making money from your site with our sport odds widget that can be directly used in your theme. Create an odds betslip from our feed with all sports and leagues available.
Version: 1.1
Plugin URI: https://www.wordpress.org/plugins/fa-sport-odds/
Author: Betfinal
Author URI: http://www.betfinal.com
License: GPL2
Text Domain: fa-sport-odds
Domain Path: /languages/
*/

if( !defined( 'ABSPATH' ) )
	exit;

include __DIR__ . '/fa-sport-odds-views.php';
include __DIR__ . '/fa-sport-odds-widgets.php';


register_activation_hook(__FILE__, array('FA_SportOdds', 'activation'));
register_deactivation_hook(__FILE__, array('FA_SportOdds', 'deactivation'));
	
class FA_SportOdds {
	
	const DB_VERSION = 1;
	const WP_MIN_VERSION = 3.6;
	
	private static $instance = null;
	
	public $options = null;
	
	public static function get_instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new static;
		}
		return self::$instance;
	}
	
	public static function init() {
		$obj = FA_SportOdds::get_instance();
	}
	
	private function __construct() {
		
		$this->options = get_option('fa-sport-odds');

		add_action('admin_menu', array(__CLASS__, 'admin_account_page') );
		add_action('admin_menu', array(__CLASS__, 'admin_odds_translation') );

		if (empty($this->options))
			$this->check_compatibility();
		else if (! isset($this->options['status'])) {
			if (empty( $this->options['not-registered-notice-dismissed'] ))
				add_action( 'admin_notices', array(__CLASS__, 'admin_notice_verification' ) );
		}

		add_action( 'widgets_init', array(__CLASS__, 'register_widgets') );
		add_action( 'wp_ajax_fa_sportodds_getleagues', array(__CLASS__, 'get_available_leagues'));
		add_action( 'wp_enqueue_scripts', array(__CLASS__, 'enqueue_styles' ) );
		add_action( 'admin_enqueue_scripts', array(__CLASS__, 'enqueue_styles' ) );
		add_action( 'wp_ajax_fa_sport_odds_not_registered_notice', array(__CLASS__, 'ajax_not_registered_notice'));
		add_action( 'fa-sportodds-scheduled_check_application', array(__CLASS__, 'check_application'));		
	}

	public static function activation() {
		if (! wp_next_scheduled ( 'fa-sportodds-application' )) {
			wp_schedule_event(time(), 'hourly', 'fa-sportodds-scheduled_check_application');
		}
	}
	
	public static function deactivation() {
		wp_clear_scheduled_hook('scheduled_check_application');
		delete_option('fa-sport-odds'); // remove registration data but keep translations
	}
	
	public static function check_application() {
		$obj = FA_SportOdds::get_instance();
		$status = $obj->options['status'];
		$authkey = $obj->options['authkey'];

		if ($status != 'pending' || empty($authkey))
			return false;
			
		$post = array('r' => 'validate', 'authkey' => $authkey);
		
		$post_string = http_build_query($post);
		$data_length = strlen($post_string);
		$con = fsockopen('www.finalaffiliates.com', 80);
		fwrite($con, "POST /wp-content/plugins/fa-wp-reg/fa-wp-reg.php HTTP/1.1\r\n");
		fwrite($con, "Host: www.finalaffiliates.com\r\n");
		fwrite($con, "Content-Type: application/x-www-form-urlencoded\r\n");
		fwrite($con, "Content-Length: {$data_length}\r\n");
		fwrite($con, "Connection: close\r\n\r\n");
		fwrite($con, $post_string);
		$headers = $data = '';
		do {
			$header .= fgets ( $con, 128 );
		} while ( strpos ( $header, "\r\n\r\n" ) === false );
		while (!feof($con)) {
			$data .= fgets($con, 128);
		}
		fclose($con);

		$data = json_decode($data);
		
		if (empty($data->ia_username) || empty($data->ia_password) || empty($data->link_desktop) || empty($data->link_mobile))
			return false;

		$obj->options['ia_username'] = $data->ia_username;
		$obj->options['ia_password'] = $data->ia_password;
		$obj->options['link_desktop'] = $data->link_desktop;
		$obj->options['link_mobile'] = $data->link_mobile;
		$obj->options['status'] = 'approved';
		update_option('fa-sport-odds', $obj->options);
		
		wp_clear_scheduled_hook('scheduled_check_application');
		
		return true;
	}
	
	public static function check_existing_user() {
		$obj = FA_SportOdds::get_instance();
		
		if (!isset($_POST['fa_sport_odds-EMAILEXISTING']) || !isset($_POST['fa_sport_odds-SECRETANSWER']))
			return false;
		
		$post = array('r' => 'connect_existing', 'email' => $_POST['fa_sport_odds-EMAILEXISTING'], 'answer' => $_POST['fa_sport_odds-SECRETANSWER']);
		
		$post_string = http_build_query($post);
		$data_length = strlen($post_string);
		$con = fsockopen('www.finalaffiliates.com', 80);
		fwrite($con, "POST /wp-content/plugins/fa-wp-reg/fa-wp-reg.php HTTP/1.1\r\n");
		fwrite($con, "Host: www.finalaffiliates.com\r\n");
		fwrite($con, "Content-Type: application/x-www-form-urlencoded\r\n");
		fwrite($con, "Content-Length: {$data_length}\r\n");
		fwrite($con, "Connection: close\r\n\r\n");
		fwrite($con, $post_string);
		$headers = $data = '';
		do {
			$header .= fgets ( $con, 128 );
		} while ( strpos ( $header, "\r\n\r\n" ) === false );
		while (!feof($con)) {
			$data .= fgets($con, 128);
		}
		fclose($con);

		$data = json_decode($data);

		if (empty($data->ia_username) || empty($data->ia_password) || empty($data->link_desktop) || empty($data->link_mobile))
			return false;

		$obj->options['ia_username'] = $data->ia_username;
		$obj->options['ia_password'] = $data->ia_password;
		$obj->options['link_desktop'] = $data->link_desktop;
		$obj->options['link_mobile'] = $data->link_mobile;
		$obj->options['status'] = 'approved';
		$obj->options['not-registered-notice-dismissed'] = 1;
		update_option('fa-sport-odds', $obj->options);
		
		wp_clear_scheduled_hook('scheduled_check_application');

		return true;
	}
	
	public function ajax_not_registered_notice() {
		$obj = FA_SportOdds::get_instance();
		$obj->options['not-registered-notice-dismissed'] = 1;
		update_option('fa-sport-odds', $obj->options);
	}

	public static function register_widgets() {
		register_widget('FA_SportOdds_Odds_Widget');
	}

	public static function enqueue_styles() {
		if (is_admin()) {
			wp_enqueue_script( 'fa-sportodds-admin', plugin_dir_url( __FILE__ ) . 'fa-sportodds-admin.js', array( 'jquery' ), '1.0', true  );
		}
		else {
			wp_enqueue_style( 'fa-sportodds-style', plugin_dir_url( __FILE__ ) . 'fa-sportodds.css' ); 
			wp_enqueue_script( 'fa-sportodds-script', plugin_dir_url( __FILE__ ) . 'fa-sportodds.js', array('jquery'), '1.0', true );
			wp_enqueue_script( 'fa-date-script', plugin_dir_url( __FILE__ ) . 'dateformat.js');
		}
	}

	public static function admin_account_page() {
	    add_submenu_page(
	        'options-general.php',
	        'FA Sport Odds MyAccount',
	        'FA Sport Odds MyAccount',
	        'manage_options',
	        'fa-odds-account-page',
	        array(__CLASS__, 'admin_account_page_callback' ) );
	}
	
	public static function admin_account_page_callback() {
		$obj = FA_SportOdds::get_instance();

		if (isset($_POST['fa-sport-odds-translation-nonce-field'])) {
			if (wp_verify_nonce( $_POST['fa-sport-odds-translation-nonce-field'], 'fa-sport-odds-translation' ) 
				&& check_admin_referer( 'fa-sport-odds-translation', 'fa-sport-odds-translation-nonce-field' )) {
			
				$trans = get_option('fa-sport-odds-translation');
				$trans[$_POST['value']] = $_POST['new_value'];
				update_option('fa-sport-odds-translation', $trans);			
			}
		}

		if (isset($_GET['translations']) && $_GET['translations'] == 'delete' && $_GET['authkey'] == $obj->options['authkey']) {
			$trans = get_option('fa-sport-odds-translation');
			unset($trans[$_GET['value']]);
			update_option('fa-sport-odds-translation', $trans);	
		}
		
		if (isset($_POST['fa-sport-odds-reg-nonce-field'])) {
			if (wp_verify_nonce( $_POST['fa-sport-odds-reg-nonce-field'], 'fa-sport-odds-reg' ) 
				&& check_admin_referer( 'fa-sport-odds-reg', 'fa-sport-odds-reg-nonce-field' )) {
				
				if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
				    $ip = $_SERVER['HTTP_CLIENT_IP'];
				} elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
				    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
				} else {
				    $ip = $_SERVER['REMOTE_ADDR'];
				}
				$post = array('r' => 'connect', 'd' => $_SERVER['SERVER_NAME'], 'ip' => $ip,
								'u' => $_POST['fa_sport_odds-USERNAME'], 'n' => $_POST['fa_sport_odds-NAME'],
								'e' => $_POST['fa_sport_odds-EMAIL'], 'a' => $_POST['fa_sport_odds-SECRETPASSWORD']);
				
				$post_string = http_build_query($post);
				$data_length = strlen($post_string);
				$con = fsockopen('www.finalaffiliates.com', 80);
				fwrite($con, "POST /wp-content/plugins/fa-wp-reg/fa-wp-reg.php HTTP/1.1\r\n");
				fwrite($con, "Host: www.finalaffiliates.com\r\n");
				fwrite($con, "Content-Type: application/x-www-form-urlencoded\r\n");
				fwrite($con, "Content-Length: {$data_length}\r\n");
				fwrite($con, "Connection: close\r\n\r\n");
				fwrite($con, $post_string);
				$headers = $data = '';
				do {
					$header .= fgets ( $con, 128 );
				} while ( strpos ( $header, "\r\n\r\n" ) === false );
				while (!feof($con)) {
					$data .= fgets($con, 128);
				}
				fclose($con);
				$data = json_decode($data);
				
				
				$obj->options['authkey'] = $data->authkey;
				$obj->options['status'] = 'pending';
				update_option('fa-sport-odds', $obj->options);
				
				FA_SportOdds_View::PendingPage();
			}
			else {
				wp_die('Verification process failed for posting new account.');
			}
		}
		else if ($obj->options['status'] == 'approved') {
			FA_SportOdds_View::AccountPage();
		}
		else if ($obj->options['status'] == 'pending') {
			if (true === FA_SportOdds::check_application())
				FA_SportOdds_View::AccountPage();
			else 
				FA_SportOdds_View::PendingPage();
		}
		else {
			if (true === FA_SportOdds::check_existing_user())
				FA_SportOdds_View::AccountPage();
			else
				FA_SportOdds_View::RegistrationPage();
		}
	}

	public static function admin_odds_translation() {
	    add_submenu_page(
	        'options-general.php',
	        'Odds Translation',
	        'Odds Translation',
	        'manage_options',
	        'odds-translation-page',
	        array(__CLASS__, 'admin_odds_translation_callback' ) );
	}

	public static function admin_odds_translation_callback() {
		include_once (dirname(__FILE__) . '/fa-odds-translation.php');
	}
	
	public static function admin_notice_verification() {
		$class = 'notice notice-error fa-sport-odds-not-registered-notice is-dismissible';
		$message = __( 'Please register your account before start using our FA Sport Odds widget, <a href="'.admin_url('options-general.php?page=fa-odds-account-page').'">more info</a>.', 'fa-sports-odds' );
	
		printf( '<div class="%1$s"><p>%2$s</p></div>', $class, $message ); 	
	}
	
	private function check_compatibility() {
		if ( version_compare( $GLOBALS['wp_version'], self::WP_MIN_VERSION, '<' ) ) {
			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			deactivate_plugins( __FILE__ );
			if ( isset( $_GET['activate'] ) ) {
				exit( sprintf( __( 'FA Sports Odds requires WordPress version %s or greater.', 'fa-sport-odds' ), self::WP_MIN_VERSION ) );
			}
		}
		$this->options = array('compability'=>true);
		
		update_option('fa-sport-odds', $this->options);
	}

	public function get_feed($bid = 1, $lid = false, $style = false) {
		$league_query = ($lid !== false) ? '&lid=' . (int)$lid : '';
		$style = ($style === 'fra') ? '&style=Fractional' : '';
		$xml = simplexml_load_file("http://promo.betfinal.com/wp-content/plugins/odds-feeder/proxy.php?bid={$bid}{$league_query}{$style}");
		
		return $xml;
	}
	
	public function get_available_sports() {
		$sports = array(
			1 => "Football", 2 => "Basketball", 3 => "American Football", 6 => "Tennis", 7 => "Baseball", 8 => "Ice Hockey", 9 => "Specials",
			10 => "Handball", 11 => "Rugby", 12 => "Golf", 13 => "Snooker & Pool", 14 => "Motor Racing", 15 => "Darts", 16 => "Cycling",
			17 => "Poker", 18 => "Speedway", 19 => "Volleyball", 20 => "Boxing", 21 => "Athletics", 22 => "Cricket", 23 => "Hockey",
			24 => "Floorball", 25 => "Futsal", 26 => "Table Tennis", 27 => "Bowls", 28 => "Winter sports", 29 => "Hurling", 30 => "Sailing",
			31 => "Water Polo", 32 => "Beach Volley", 33 => "Beach Soccer", 34 => "Badminton", 35 => "Rugby Union", 36 => "Trotting",
			37 => "Curling", 38 => "Summer Olympic", 39 => "Bandy", 40 => "Beach Handball", 41 => "Aussie Rules", 42 => "Winter Olympic",
			43 => "MMA", 45 => "Swimming", 47 => "Rowing", 48 => "Triathlon", 55 => "Fencing", 59 => "Cricket", 60 => "Surfing", 
			64 => "E-Sports", 65 => "Chess"
		);
		asort($sports);
		return $sports;
	} 
	
	public static function get_available_leagues() {
		$fa_sport_odds_cache = get_option('fa_sport_odds_cache');

		if($fa_sport_odds_cache['bid'] == $_REQUEST['bid']){
			if($fa_sport_odds_cache['timestamp'] > time()){

				$json_array = $fa_sport_odds_cache['data'];
				echo json_encode($json_array);

			}
			else{

				$xml = FA_SportOdds::get_instance()->get_feed($_REQUEST['bid']);

				$leagues = array();
				foreach ($xml->Event as $event) {
					$leagues[strval($event->attributes()->LeagueID)] = strval($event->attributes()->League);
				}
				asort($leagues);
				
				$json_array = array();
				foreach ($leagues as $id => $name) {
					$json_array[] = array('id' => $id, 'name' => $name);
				}

				$fa_sport_odds_cache = array('bid' => $_REQUEST['bid'], 'data' => $json_array, 'timestamp' => (time() + (24*60*60)));
				update_option('fa_sport_odds_cache', $fa_sport_odds_cache);
				
				echo json_encode($json_array);

			}


		}else {
			$xml = FA_SportOdds::get_instance()->get_feed($_REQUEST['bid']);

			$leagues = array();
			foreach ($xml->Event as $event) {
				$leagues[strval($event->attributes()->LeagueID)] = strval($event->attributes()->League);
			}
			asort($leagues);
			
			$json_array = array();
			foreach ($leagues as $id => $name) {
				$json_array[] = array('id' => $id, 'name' => $name);
			}

			$fa_sport_odds_cache = array('bid' => $_REQUEST['bid'], 'data' => $json_array, 'timestamp' => (time() + (24*60*60)));
			update_option('fa_sport_odds_cache', $fa_sport_odds_cache);
			
			echo json_encode($json_array);

		}
		wp_die(false);

		
		
	}
	
	public static function translate(&$object) {
		$trans = get_option('fa-sport-odds-translation');
		if (! is_array($trans))
			$trans = array();
		
		if (is_array($object) && isset($object['home_team'])) {
			if (array_key_exists($object['home_team'], $trans))
				$object['home_team'] = $trans[$object['home_team']];
		}
		if (is_array($object) && isset($object['away_team'])) {
			if (array_key_exists($object['away_team'], $trans))
				$object['away_team'] = $trans[$object['away_team']];
		}
		
		if (is_array($object) && isset($object['LeagueName'])) {
			if (array_key_exists($object['LeagueName'], $trans))
				$object['LeagueName'] = $trans[$object['LeagueName']];
		}
	}
	
}

add_action('setup_theme', array('FA_SportOdds', 'init'));

?>
